(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     75235,       1574]
NotebookOptionsPosition[     71555,       1514]
NotebookOutlinePosition[     72049,       1532]
CellTagsIndexPosition[     72006,       1529]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 7, Section 7.5", "Section",ExpressionUUID->"3ee60461-44c2-40ac-9506-5ddf58e33a63"],

Cell[TextData[{
 "We start by defining a function ",
 StyleBox["secular", "Input"],
 " that derives a secular perturbation theory for any number of masses with \
given orbital elements.  In this version we have removed all the printing \
commands.  ",
 StyleBox["Sect.7.3.nb",
  FontWeight->"Bold"],
 " contains the version that prints out the results."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"37be38bd-2803-4bd7-ac96-d8eee2b1b416"],

Cell["\<\
(* 
               ==== Secular perturbation solver ==== 
                       v1.0 February 1993 
                         Carl D. Murray             
*)


secular::usage = \"secular[nbody, m, a, ecc, inc, peri, node, n,
\trp, j2, j4] determines the secular perturbation solution for
\tthe gravitational interaction of nbody bodies with mass ratios
\tm, semi-major axes, a, eccentricities, ecc, inclinations, inc,
\tlongitudes of pericentre, peri, longitudes of ascending node,
\tnode, mean motions, n (in degrees/year) which are orbiting a
\tcentral body of radius, rp with J2 and J4 values, j2 and j4.
\tThe function defines ecalc and icalc which can be used to plot
\tthe time variation of the eccentricity and inclination of
\tany of the bodies.\";

secular[nbody_, m_, a_, ecc_, inc_, peri_, node_, n_, 
        rp_, j2_, j4_] :=
(* 
   Based on the theory given in Dermott & Nicholson, Nature,
   319, 115-120.
   
   nbody : number of bodies
   m     : masses of bodies
   a     : semi-major axes of bodies
   ecc   : eccentricities of bodies
   inc   : inclinations of bodies
   peri  : longitudes of pericentre of bodies
   node  : longitudes of ascending nodes of bodies
   n     : mean motion (in degrees/year) of bodies
   rp    : radius of central object
   j2    : J2 of central object
   j4    : J4 of central object
*)  
Module[{rpa2 = N[(rp/a)^2], rpa4 = N[(rp/a)^4], j22=j2*j2,
        mred = 1+m},
(* 
   Set the initial values of h, k, p, q
*)
hinit = ecc*Sin[N[peri]];
kinit = ecc*Cos[N[peri]];
pinit = N[inc*Sin[node]];
qinit = N[inc*Cos[node]];
(*
   Define the alpha, alphabar functions from the D&N paper
*)
alpha[ j_, k_ ] := a[[k]]/a[[j]] /; k <  j;
alpha[ j_, k_ ] := 0             /; k == j;
alpha[ j_, k_ ] := a[[j]]/a[[k]] /; k >  j;
alphabar[ j_, k_ ] := 1             /; k <  j;
alphabar[ j_, k_ ] := 0             /; k == j;
alphabar[ j_, k_ ] := alpha[ j, k ] /; k >  j;
(*
  Define the Laplace coefficient function using a numerical
  integration
*)
laplace[ s_, jj_, aa_ ] := 
  If[aa != 0,
     NIntegrate[ N[ (1/Pi)*(Cos[jj*x])/((1-2aa*Cos[x]+aa^2)^s) ],
                {x, 0, 2Pi} ],
     0];
(*
  Define the elements of the matrices A and B
*)
A[ j_, k_ ] := -(1/4)*m[[k]]*(n[[j]]/mred[[j]])*
                 alpha[j,k]*alphabar[j,k]*
                 laplace[3/2, 2, alpha[j,k]] /; j != k;
A[ j_, k_ ] := n[[j]]*
               ((3/2)*j2*rpa2[[j]] - (9/8)*j22*rpa4[[j]] -
                (15/4)*j4*rpa4[[j]] +
                ((1/4)/mred[[j]])*
                         Sum[If[l != j,
                            m[[l]]*
                            alpha[j,l]*alphabar[j,l]*
                            laplace[3/2, 1, alpha[j,l]],
                            0],
                          {l,nbody}]) /; j == k;
B[ j_, k_ ] := (1/4)*m[[k]]*(n[[j]]/mred[[j]])*
                 alpha[j,k]*alphabar[j,k]*
                 laplace[3/2, 1, alpha[j,k]] /; j != k;
B[ j_, k_ ] := -n[[j]]*
               ((3/2)*j2*rpa2[[j]] - (27/8)*j22*rpa4[[j]] -
                (15/4)*j4*rpa4[[j]] +
                ((1/4)/mred[[j]])*
                         Sum[If[l != j,
                            m[[l]]*
                            alpha[j,l]*alphabar[j,l]*
                            laplace[3/2,1,alpha[j,l]],
                            0],
                          {l,nbody}]) /; j == k;
(*
  Construct the two matrices
*)
bigA = Array[ A, {nbody,nbody} ];
bigB = Array[ B, {nbody,nbody} ];
(*
  Solve the resulting eigensystems
*)
esA = Eigensystem[ bigA ];
esB = Eigensystem[ bigB ];
(*
  Extract the two sets of eigenfrequencies ...
*)
g = esA[[1]];
f = esB[[1]];
(*
  ... and the corresponding (unscaled) eigenvectors
*)
ebarji = Transpose[esA[[2]]];
ibarji = Transpose[esB[[2]]];
(*
  Determine the values of Sin[beta] and Sin[gamma] and hence
  the scaling of the eigenvectors
*)
fsbeta = LinearSolve[ebarji, hinit];
fcbeta = LinearSolve[ebarji, kinit];
beta = ArcTan[fcbeta, fsbeta];
sbeta = Sin[beta];
fsgamma = LinearSolve[ibarji, pinit];
fcgamma = LinearSolve[ibarji, qinit];
gamma = ArcTan[fcgamma, fsgamma];
sgamma = Sin[gamma];
emag = fsbeta/sbeta;
imag = fsgamma/sgamma;
eji = Map[Times[#,emag]&, ebarji];
iji = Map[Times[#,imag]&, ibarji];
gr = N[g Degree];
fr = N[f Degree];
(*
  Use these values to determine e and I as functions of time
*)
ejcalc[j_, t_] := 
  Sqrt[(Plus @@ (eji[[j]]*Sin[gr*t+beta]))^2 + 
       (Plus @@ (eji[[j]]*Cos[gr*t+beta]))^2];
ijcalc[j_, t_] := 
  N[
   Sqrt[(Plus @@ (iji[[j]]*Sin[fr*t+gamma]))^2 + 
        (Plus @@ (iji[[j]]*Cos[fr*t+gamma]))^2]/Degree]
];                                                                        
\
\>", "Input",
 PageWidth:>Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[1]:=",ExpressionUUID->"5c704d32-0f85-4403-a895-45a1604b6428"],

Cell[TextData[{
 "Apply ",
 StyleBox["secular", "Input"],
 " to derive a secular theory for the Jupiter-Saturn system."
}], "Text",
 PageWidth:>Infinity,
 CellFrame->True,
 CellChangeTimes->{3.811396610173134*^9},
 ShowSpecialCharacters->False,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2e9e3caf-c152-46bc-92b1-e90ba07337d9"],

Cell["\<\
secular[2, 
        {1./(1047.355), 1./(3498.500)},
        {5.202545, 9.554841},
        {0.0474622, 0.0575481},
        {1.30667, 2.48795} Degree,
        {13.983865, 88.719425} Degree,
        {100.0381, 113.1334} Degree,
        {30.3374, 12.1890},
        0,
        0,
        0
        ]\
\>", "Input",
 PageWidth:>Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[8]:=",ExpressionUUID->"07b26879-78d8-4f11-bd0a-d76ed7a87d31"],

Cell[TextData[{
 "Now define a function ",
 StyleBox["proper", "Input"],
 " that will calculate proper elements for a test particle in this system \
with a given set of orbital elements."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.8113967172041388`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"662f21a2-b317-4507-af2b-95832ea6ae72"],

Cell["\<\
proper[nbody_, m_, a_, ecc_, inc_, peri_, node_, n_, rp_, j2_, j4_,
       atest_, etest_, itest_, ptest_, nodtest_, dummy_, time_] :=
Module[{ntest=360./atest^(3/2)},
(*
secular[nbody, m, a, ecc, inc, peri, node, n, rp, j2, j4];
*)
alphaj =    (atest/a /. {x_ :> 1/x /; x>1});
alphabarj = (atest/a /. {x_ :> 1   /; x>1});
bigNj = (1/8)*alphaj*alphabarj*Map[laplace[3/2, 1, #]&, alphaj];
bigPj = (1/8)*alphaj*alphabarj*Map[laplace[3/2, 2, #]&, alphaj];
bigAA = (2*ntest) * (Plus @@ (m*bigNj));
nuj   = (2*ntest) * ( (m*bigPj) . (eji) );
muj   = (2*ntest) * ( (m*bigNj) . (iji) );
h0 = Plus @@ ( (nuj/(bigAA-g)) Sin[gr*time+beta] );
k0 = Plus @@ ( (nuj/(bigAA-g)) Cos[gr*time+beta] );
eforced = Sqrt[h0^2+k0^2];
pforced = N[ArcTan[k0, h0]/Degree];
p0 = Plus @@ ( (muj/(bigAA+f)) Sin[fr*time+gamma] );
q0 = Plus @@ ( (muj/(bigAA+f)) Cos[fr*time+gamma] );
iforced = N[Sqrt[p0^2+q0^2]/Degree];
nodforced = N[ArcTan[q0, p0]/Degree];
h = etest*Sin[N[ptest]];
k = etest*Cos[N[ptest]];
p = N[itest*Sin[nodtest]];
q = N[itest*Cos[nodtest]];
nusin = h - h0;
nucos = k - k0;
efree = Sqrt[nusin^2+nucos^2];
musin = p - p0;
mucos = q - q0;
ifree = N[ArcSin[Sqrt[musin^2+mucos^2]]/Degree];
pbeta  = N[ArcTan[nucos, nusin]/Degree]-bigAA*time;
pgamma = N[ArcTan[mucos, musin]/Degree]+bigAA*time;
pbetar  = N[pbeta  Degree];
pgammar = N[pgamma Degree];
{atest,bigAA,eforced,pforced,iforced,nodforced}
];\
\>", "Input",
 PageWidth:>Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[9]:=",ExpressionUUID->"c623892b-23df-48e2-8ce8-3f29f51004fe"],

Cell[TextData[{
 "Create a list, ",
 StyleBox["data", "Input"],
 ", of the values of the semi-major axis (",
 StyleBox["atest", "Input"],
 "), the free precession rate (",
 StyleBox["bigAA", "Input"],
 "), the forced eccentricity (",
 StyleBox["eforced", "Input"],
 "), pericentre (",
 StyleBox["pforced", "Input"],
 "), inclination (",
 StyleBox["iforced", "Input"],
 ") and node (",
 StyleBox["nodforced", "Input"],
 ") for semi-major axes up to 30 AU."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2f8a5dda-193b-4399-af6a-6654ed22c761"],

Cell["\<\
data = Table[
       proper[2, 
        {1./(1047.355), 1./(3498.500)},
        {5.202545, 9.554841},
        {0.0474622, 0.0575481},
        {1.30667, 2.48795} Degree,
        {13.983865, 88.719425} Degree,
        {100.0381, 113.1334} Degree,
        {30.3374, 12.1890},
        0,
        0,
        0,
        ai, 0.15, 10 Degree, 42 Degree, -10 Degree, 149.07, 0.],
{ai,0.0001,30.,0.05}];\
\>", "Input",
 PageWidth:>Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[10]:=",ExpressionUUID->"f1162b10-f35b-4ad3-9f60-6b592fc5f88e"],

Cell["Take the transpose of the resulting file ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"564a21d4-8a15-4db0-b1b2-c438826011fc"],

Cell["tdata = Transpose[data];", "Input",
 PageWidth:>Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[11]:=",ExpressionUUID->"c77417f9-edc5-4dd7-bb9a-72d807ea7ecf"],

Cell["\<\
... and extract the values of the semi-major axis, free precession rate, and \
the forced values of the eccentricity, longitude of pericentre, inclination \
and longitude of ascending node.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.811396658020967*^9, 3.811396666938703*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6ed3178b-b2be-4db8-ba71-6f8ec0cc31d0"],

Cell["\<\
adat = tdata[[1]];
bigAdat = tdata[[2]];
efdat = tdata[[3]];
pfdat = tdata[[4]];
ifdat = tdata[[5]];
nfdat = tdata[[6]];\
\>", "Input",
 PageWidth:>Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[12]:=",ExpressionUUID->"f6e9cb09-03f4-4c91-ad16-459ddee14345"],

Cell["\<\
Plot the free precession rate as a function of semi-major axis.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9b401429-81d7-4e11-94eb-930de94e0f83"],

Cell[CellGroupData[{

Cell["\<\
bigAplot = ListPlot[Transpose[{adat,bigAdat}],
             Frame->True,PlotRange->{{0,30},{0,0.05}},
             Joined->True]\
\>", "Input",
 PageWidth:>Infinity,
 CellChangeTimes->{
  3.811396763185142*^9, {3.811397001154325*^9, 3.811397002202923*^9}},
 ShowSpecialCharacters->False,
 CellLabel->"In[18]:=",ExpressionUUID->"681867ba-2ded-409c-8fba-c6c4c571fd78"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJwtzH881HccB/DvnXPn3Pmx2yMzi1g7tSn2yCXhvD/00ExsaHtQy69ruMaF
hjrJz0z5kSLGdTNixiOPlR4PNaPxGJeVH01+LBord3V+NsQ5K6z2eL8ej9fj
9cfr8XhaiWL8w+kURe171de7fc/G6XEHM+isnvr+YLKla8sWI05jTR14e2+q
4xdqXK+Efua/paIJZEbU8BGlEbSUnDdKcmiHQdHGZgsfc3h3VZPwSH4HzjrG
32kssoaOBtujVbQ/oCz7KS+i1A60qrDKIUE/uNk0vZPXIwAb0+IBtngIliq6
c7Z7OEHwvt9ZwkvD0DXs0yo1IXAh5YVTbO9fYLlhU6Y72QPjgW/d7KMewdzl
FM+j5XsheeGab5TsMXznLt+8ZucFJnleUwyBElya/lQHLfrAVb4qs7xHBbn5
2mN1S77wcespc8fIp/BRp7fquP5+9CbA/J9ajcLxc/QmYYyRIRtLC0BvGqgc
2v33lQfQm4GMcx0f2oQeQu8ZwKDfkzRtMMTV5z4UU3Mg+5ZeFjcUCq7SwNqd
PXMwE3jRigci4OzlJ9Bl86BktX9QeuMwPOAtuN2LWABZQRAvWxgOP/z9q6Hc
/jl0se72xAxEoLcIkuvSsPmTYvQWwfVWb2KT4Cv0lsDMNcg4az0KPQ0IuRuC
rEYl6C3D7cGEK9G9MehpQdnn0mozFYueFh5PCpQLy3HorcBdS1tL0ze+Ru9f
CLDqX9/hEI/eC+AUlvDUkQnovQQxq1ClqklE7yWou4jh9PPj6K2CvsV7X3Z+
KkVvDZ7dGvAMbE5Cbx00wXn8c7uSYfeQQiKgKBJL7zaQKE5Bhcu2AVkERdo2
JxYZRqQCs6rQidZDkbRrbRN++WkQzV6piLSnEZ/1/Q+dj6VDf0wIq7eMRjye
tCpOiDLQo5P4hpDZruBM9Ohkpnl3H1t8Gj06ERmurrydmgWS/z0dQm4bM1aq
v0FPh+iKmbO/jGSjxyCTHid+yrc6ix6D0HRMdrQk5aDHIImaq/UN6lz0dMmI
8Ezs6pF89HTJz8l8rwCdAvSYZMndGe4fPI8ek1i0X/8txe0CekzCGpH7jjgU
osciDqOKFluXIvRYxM/WfnHK/yJ6emR5q9q0NrkYPT1yoGAi3q65BL1XP3NN
km5cih6b3Mxqqx9NKUOPTYpntzV2611CT5/MeIYIbRrk6OmTN1nplbtOlqOn
T7wO1S/57qxAj0Ok0fNp99wq0eMQGoMaSw2/jB6XPEi/EWZdVYUel0RmHnZe
XK1Gj0u4cmu+XFqDngHRbg0djzKrhS8++bFDecaAyMpepw7+AxRKG/A=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQfe3fPK6cQGmHWTNBYKV9c6Dn3IY0aYd3yWlqXTwr
7be11FzYPFPaQYB51dQ7N5bbv9y+nvn5GWkHbxaXnU1HltnLvH5kJsUg4yAe
fWt95pml9gFyYlm+xjIOav16Xh/fLoGaJ+NwIvWF+221JVDzZBzqktduty1d
DDVPxqFKe8uj8uuLoObJOvzkDfDT9FkENU/WoT2trELr0kKoebIOEyexc7Zn
LISaJ+vg1mrkVMm3EGqerEN428H2tMMLoObJOXhWxTy407YAap6cw+nt3bET
IxZAzZNzaPwimBBvsQBqnpzDB5MZ2zzUFkDNk3PYMllmbpkSzDx5h7LahWus
dWHmyTuwKF24IuYOM0/eIXuWX+v2Aph58g5cSf7WzKth5sk7rP2Yt1Pm+wL7
vtJCaV4GBQcn98kBuWEL7TX4ubcuk1Rw2JIusmjDqYX2B1cs8XMwVnCY2LRq
JXPYIvtoJ7sXN30UHNheTj/9/dci+6+3rzcWpyk4yKuu1V29ZzHEvAYFh7uX
+D48n7cEYt5MBYefHs7VPsuWQszbrOCgpar1of7GMoh5ZxQc4iU5/5XZrLBv
cdaTznmkAE8PAG7Q71w=
      "]], LineBox[CompressedData["
1:eJwt0nlcjXkfxvFsFYURorGk9Zw6S2ffj3O1l/ZCHJUWWoSkVHbZWmTJnphK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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 30}, {0, 0.05}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811396764529036*^9, 3.811396863988147*^9, 
  3.8113970585230494`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"77841e37-4e24-4fb1-956d-6b7feec12790"]
}, Open  ]],

Cell["\<\
Create a graphics object to denote the eigenfrequencies of the system.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cf8b70f8-e9fe-42d2-b558-00be3d00f974"],

Cell["\<\
gflines = Graphics[
           {Line[{{0.0,Abs[g[[1]]]},{30.0,Abs[g[[1]]]}}],
            Line[{{0.0,Abs[g[[2]]]},{30.0,Abs[g[[2]]]}}],
            Line[{{0.0,Abs[f[[1]]]},{30.0,Abs[f[[1]]]}}],
            Line[{{0.0,Abs[f[[1]]]},{30.0,Abs[f[[1]]]}}]}];\
\>", "Input",
 PageWidth:>Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[19]:=",ExpressionUUID->"742e3cdc-0e6e-46c5-bcf4-312132224855"],

Cell["\<\
Combine the free precession arte plots with the eigenfrequencies (see \
Fig.7.4).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5d7f88d1-17bb-491d-9de1-a291845e8ed7"],

Cell[CellGroupData[{

Cell["Show[bigAplot,gflines]", "Input",
 PageWidth:>Infinity,
 CellChangeTimes->{3.811396776521873*^9},
 ShowSpecialCharacters->False,
 CellLabel->"In[20]:=",ExpressionUUID->"f083dc9b-47f9-4338-962f-44c518c79ed4"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtzH881HccB/DvnXPn3Pmx2yMzi1g7tSn2yCXhvD/00ExsaHtQy69ruMaF
hjrJz0z5kSLGdTNixiOPlR4PNaPxGJeVH01+LBord3V+NsQ5K6z2eL8ej9fj
9cfr8XhaiWL8w+kURe171de7fc/G6XEHM+isnvr+YLKla8sWI05jTR14e2+q
4xdqXK+Efua/paIJZEbU8BGlEbSUnDdKcmiHQdHGZgsfc3h3VZPwSH4HzjrG
32kssoaOBtujVbQ/oCz7KS+i1A60qrDKIUE/uNk0vZPXIwAb0+IBtngIliq6
c7Z7OEHwvt9ZwkvD0DXs0yo1IXAh5YVTbO9fYLlhU6Y72QPjgW/d7KMewdzl
FM+j5XsheeGab5TsMXznLt+8ZucFJnleUwyBElya/lQHLfrAVb4qs7xHBbn5
2mN1S77wcespc8fIp/BRp7fquP5+9CbA/J9ajcLxc/QmYYyRIRtLC0BvGqgc
2v33lQfQm4GMcx0f2oQeQu8ZwKDfkzRtMMTV5z4UU3Mg+5ZeFjcUCq7SwNqd
PXMwE3jRigci4OzlJ9Bl86BktX9QeuMwPOAtuN2LWABZQRAvWxgOP/z9q6Hc
/jl0se72xAxEoLcIkuvSsPmTYvQWwfVWb2KT4Cv0lsDMNcg4az0KPQ0IuRuC
rEYl6C3D7cGEK9G9MehpQdnn0mozFYueFh5PCpQLy3HorcBdS1tL0ze+Ru9f
CLDqX9/hEI/eC+AUlvDUkQnovQQxq1ClqklE7yWou4jh9PPj6K2CvsV7X3Z+
KkVvDZ7dGvAMbE5Cbx00wXn8c7uSYfeQQiKgKBJL7zaQKE5Bhcu2AVkERdo2
JxYZRqQCs6rQidZDkbRrbRN++WkQzV6piLSnEZ/1/Q+dj6VDf0wIq7eMRjye
tCpOiDLQo5P4hpDZruBM9Ohkpnl3H1t8Gj06ERmurrydmgWS/z0dQm4bM1aq
v0FPh+iKmbO/jGSjxyCTHid+yrc6ix6D0HRMdrQk5aDHIImaq/UN6lz0dMmI
8Ezs6pF89HTJz8l8rwCdAvSYZMndGe4fPI8ek1i0X/8txe0CekzCGpH7jjgU
osciDqOKFluXIvRYxM/WfnHK/yJ6emR5q9q0NrkYPT1yoGAi3q65BL1XP3NN
km5cih6b3Mxqqx9NKUOPTYpntzV2611CT5/MeIYIbRrk6OmTN1nplbtOlqOn
T7wO1S/57qxAj0Ok0fNp99wq0eMQGoMaSw2/jB6XPEi/EWZdVYUel0RmHnZe
XK1Gj0u4cmu+XFqDngHRbg0djzKrhS8++bFDecaAyMpepw7+AxRKG/A=
       "]], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQfe3fPK6cQGmHWTNBYKV9c6Dn3IY0aYd3yWlqXTwr
7be11FzYPFPaQYB51dQ7N5bbv9y+nvn5GWkHbxaXnU1HltnLvH5kJsUg4yAe
fWt95pml9gFyYlm+xjIOav16Xh/fLoGaJ+NwIvWF+221JVDzZBzqktduty1d
DDVPxqFKe8uj8uuLoObJOvzkDfDT9FkENU/WoT2trELr0kKoebIOEyexc7Zn
LISaJ+vg1mrkVMm3EGqerEN428H2tMMLoObJOXhWxTy407YAap6cw+nt3bET
IxZAzZNzaPwimBBvsQBqnpzDB5MZ2zzUFkDNk3PYMllmbpkSzDx5h7LahWus
dWHmyTuwKF24IuYOM0/eIXuWX+v2Aph58g5cSf7WzKth5sk7rP2Yt1Pm+wL7
vtJCaV4GBQcn98kBuWEL7TX4ubcuk1Rw2JIusmjDqYX2B1cs8XMwVnCY2LRq
JXPYIvtoJ7sXN30UHNheTj/9/dci+6+3rzcWpyk4yKuu1V29ZzHEvAYFh7uX
+D48n7cEYt5MBYefHs7VPsuWQszbrOCgpar1of7GMoh5ZxQc4iU5/5XZrLBv
cdaTznmkAE8PAG7Q71w=
       "]], LineBox[CompressedData["
1:eJwt0nlcjXkfxvFsFYURorGk9Zw6S2ffj3O1l/ZCHJUWWoSkVHbZWmTJnphK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       
       "]]}}, {{}, {}}}, {
    LineBox[{{0., 0.006099079932152245}, {30., 0.006099079932152245}}], 
    LineBox[{{0., 0.0009634340950716988}, {30., 0.0009634340950716988}}], 
    LineBox[{{0., 0.0070625140272239425`}, {30., 0.0070625140272239425`}}], 
    LineBox[{{0., 0.0070625140272239425`}, {30., 0.0070625140272239425`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 30}, {0, 0.05}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811396777759562*^9, 3.811396864055708*^9, 
  3.811397058579433*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"6eafdb37-90bf-470c-8505-2b1cbb825cdb"]
}, Open  ]],

Cell["\<\
Plot the forced eccentricity as a function of semi-major axis (see Fig.7.5a).\
\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"94eb1f9f-cb11-48e0-b250-782c103d3cd2"],

Cell[CellGroupData[{

Cell["\<\
efplot = ListPlot[Transpose[{adat,efdat}],
             Frame->True,PlotRange->{{0,30},{0,0.1}},
             Joined->True]\
\>", "Input",
 PageWidth:>Infinity,
 CellChangeTimes->{
  3.811396789559244*^9, {3.811397013057804*^9, 3.811397013640136*^9}},
 ShowSpecialCharacters->False,
 CellLabel->"In[21]:=",ExpressionUUID->"b54344f3-f291-4818-a064-4aa0cce1d443"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], 
     LineBox[{{0.0001, 2.0550043554692464`*^-12}, {0.050100000000000006`, 
      0.000011809817910939926`}, {0.10010000000000001`, 
      0.00006956106996244052}, {0.1501, 0.00020309852527856912`}, {0.2001, 
      0.00044897049493826657`}, {0.2501, 0.0008597580685927136}, {
      0.30010000000000003`, 0.0015184178605048583`}, {0.3501, 
      0.00256737817000056}, {0.4001, 0.004276625714029046}, {0.4501, 
      0.007231117813353613}, {0.5001, 0.012983843938760769`}, {0.5501, 
      0.027480823885351505`}, {0.5919179014617375, 0.1}}], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/WrJ6k2ny5/Yz5oJAjvt16s+aZ539on978375sgs
3mHvub9W1iL9mX3WPs34C1VL7R9FiG+/yPDCPsUyzm3R5nn2NZ82BGTPemnf
rVEWZtgx016sx+sVi8lre5574umXL0yDmvfGvqb0bPYGm6lQ897ZL7pbzbHS
fYp94Zru2xkMH+z/ft7CUb95sr1dZcQK07Mf7L9u/TvFIX6yPbebainTrI/2
Idsn16tbTLa/IfTJ8XzaJ/uYPWFpCsaT7Zfe38c3x/izfb6Qu80Zz8lQ877Y
z3G6IaRcCTPvi/1Ec0839oMw877aZ35ZWjZLZQrUvG/2a5J5o+pXT4Ga992e
98/z+8tTpkLN+2GvKVXx3jxnGtS8H/aV0d3iNj+mQ837aa+09UmefNksqHm/
7M/kXTrAdn0e1Lzf9jPvBn0+t28x1Lw/9q/YcxziFNfZb5w07b9E1h94+AMA
AJTGkQ==
      "]], LineBox[CompressedData["
1:eJw113lUU2cax/GwCKhEIOxhS8iGuNQCYqXK/VlFFAUXtFKUMlIBhaKlgkDF
USrV0YIUW0QUELIrSxBURC1UizPTuiIWodraYXBBwRGKoi3CUH3enJOTc889
+Zzv8+a5f0Qcs2l5rDGPx7s6+v7r8zS/7URl3DB3qOivVwPXLuifc2302jm6
Y97BPQ2c5m7jhGLfES7b0DRm4WkDN7PtYpIfj4fI+O+59qt6rmzW5JuH4niY
mhz0Q1WqhjNT7Q8wujJ6f+fMJNdCFffx2Jdl8b5GGNMp7F21Rcm1boo2v1pk
hOGJnYVHvisnzxjTLQ/eSVpcTp4xvh2JD7xjXE6eMaKuzc5a01bGJb32TPC1
dWTR5sYy8kyw69F2YcHJMvJMkbxkx76h+jLyTHFYuc3f7Psy8kwx60RixaWb
zBuDUG1v5v3HzBuDVrPfhheYsz4zSN47ki2Vsz4zLA734rUHsz4zmG95YdqV
WE6eOQRxa1d15peTZw6T8R/c3d7APAscGXHn0juZZ4EDysi8/ZZK8iwQceDs
49IZSvLGojnjeUHKR+z8xiLu/tFdT/OU5I1D8cJDSwbOKckbB7+/XwuIfcS8
cZgs33JwkpOKvPE4et0w2We+irzx4NdMaYxNUZFnCXufohMnlCryLCHkt12e
0KIizxJ+tWuurBthHh/ytcnL9FPU5PFxqFqju7RaTd4EvBrjuvf8HjV5E+Df
vFOxrV5N3gR8v8HubF+XmjwrrGrPPC4QaMizgsNS24TWQA3n+rjTX8izhtVM
T09FooZb4u6QEOprDYecJx28Qg23c9nCkh1x1ijONQ8Iv6DhTmVnXq8rsoZJ
kXm6da+G6643mDy4bI3hugUB3o5a8mxQ6ngvIx9a8mxwr2VRjP8GLXk2qA3f
P8UiX0ueDd4f3jY0UK8lzwaSaSP67l+YJ4BfbEZ+i7GOPAHOFVRGHpDryBMg
szZU47FQR54A8U0+dcsTdOQJMDd32nObvTrybJGRObB9ll7HLX3t2SJ6S1ZQ
VTPzbHEjdVAUcJd5tqgOP5dUO8g8W3xxqWL4Dl9Pnh3CDTP7UsR68uwwLXFy
mNRHT54d9D1FFzM4PXl2MJXyD19foCfPDoLeZPy+mHn26PpqUuyuhcyzh9WZ
a6e7wDx7eMzldWf7Mc8e/761WuIpY549nh51dX/HlnkO8PEx8xaNsHkdkLCq
6aBbN5vXAU5VtQvWtbB5HUafv9Bc19NsXgfU/VlwKraEnZ8jfk/rvrIqi3mO
yI7p/sl0HfMc8bHwVUNGEPMcUTylwKJJxjxHLNo7uKfDlHlOWHR1pOnHTi15
TqiscIvIb2L74oSKAcvCiYfZvjhhUsXZ5txUti9O6P9lU+mpMLYvzriSNv6n
w3LmOWPoz/0lfq/YPjtD37o+Mv0G22dnqIynrIvWsn12hnf1+Zf/TWfPhxCr
g1yiTUI05AnR97zRt8mZeUI8mLrCwuOhmjwh0o5kv+tzUk2eEJ0XvaWCLDV5
LjCWx+d0LVKT54KohObMX+3V5LmgwKNtSfBdFXkuuHs7b2irXkWeC96Wf7e1
P1lFniu65wqsZs9SkeeK2Zem+fItVOS5YsV7M65Ob1OS54pblVLvSp2SPFco
H/SId29TkucGwY6PzYYilOS54euMb/wj3lWS54bPfzDVDcqY54Y9Ibs/myFk
nhtS1JOiY52Z5w6b8sDESinz3LHzt59e8WYzzx3hPJma/xHz3DEzfiBQUsg8
d2ycsz51agfzPHCKf/x+nReb1wPN49L0rdlsXg/cm3YuN7yHnZ8H/nige1Yd
xX4PD0Q3x7zjfUvN7UtNduHzRLgSVFL/4H0N52U1/qTWWYTsHO3RoZ813Hm9
Ogy+IuQvdgvIXqvlVr8X+LBjsQhRgWPuGR5quWe3b2VtjhPB8l7v7psbdW+8
HSIUPi15trlf98YrEiEkO10x91P9G69u9H70zTVTevVvvMsixH/+z4IVMUff
ePdF6BNvfmDVcpT6xGh5kuT98J1j1CeGx/vXt31ddIz6xFgScYb/tP8Y9Ykx
Mjkic3heBfWJcSDI/907eRXUJ8Zwn5dNY2sF9Ymx0SrtxSPrSuoT4/5Eu0/r
gyupT4x80fOorPRK6hOj4ROXDytVldTnCbML35wv/aGS+jxh9FH+k8ZH5Pl6
IkRVMjvZvIr6PBHGj/RzEFVRnyd2lduNGzu9ivo8YW69YXXp/Crq80TAjH0P
PVdWUZ8ndr5VLPv5b+Rd9kRw4QqfoQ3k3R/tudHL1X5CHk+CNv3G5RNSyXOW
wP6YUW7Pliruwus+CYpCOr40pLI+Cd4OHbgV9Snrk6DxxcuwC0msTwI/r0OP
Vq9nfRI499zblxdDXp0EL2PdXOvWsD4JNA2XQwSrWJ8Ey5fsi+9bxvqkmKhz
cMsLZX1SpF1fcF4WwvqkKO1sj+wJZn1SZKcEbHUMZn1SLGg9PdQRzPqksMk8
Uh0bwvqkmOzv/fxxGOuTIr9/2obSlaxPCpPF/4gzfMj6pPAzyjEsT2B9Mpyd
N96sMZ31yfCw7mbLxL2sT4aFRrNaWkpZnww2a0Pan51ifTIM/npG+fMN1idD
zuOd3/7Yz/pkKFy3PdfRsZr6ZAjwupohRDX1yRAofDTHf2M19cnQk8jf015e
TX1yCIUXlFtvV1OfHJ/V+Bn0Lgbqk2PGYIbzHzEG6pPjxbyife61BuqTY/pK
l6AnpjXUJ0fx5hthX06vob7R73ctW7o+sYb65Ej/cbepi66G+uTYNP/GnaXd
NdQnh5nuZnurz3HqU+DF0oiCr7KPU58C/zuT3Fdy9zj1KfB52n8uzQ+qpT4F
dn8QleNQX0t9CuTMO5zS7V9HfQrkLs/yMP5XHfUpoPxm0E+ecIL6FDjCfyvs
ouQk9SngOmfdrqkvTlKfApY9McW3e05RnxdkX4TuuGNxmvq8kGdS15WysoEb
8NGutXf3Avs/838zuaOS
      "]], LineBox[CompressedData["
1:eJw91H9M1HUcx/ELSw0iYFpJLn6lB35/ftxFKZXf12gsZwcbylyJiiR3mxuo
ieRqsw4RvA24WyaNYy5p5vfu+OWd9/U82ShWa4xkVJxxVoyh/PCcJDgxB1mm
+77tu3333fef5x7v7/uzb/r7+zZbYgwGw8aH96NngfrhyZF3ObS4Hl0Xlbt/
RKorrRzSLBebHDkhxVH1wcp4G4fuN7vK+o1BJSsh7rzq4pC943j/3oOa8p3n
6wIEOPw6kefMig8oxbkbor8NcEjJqHDMjvn13hQH2bJgXBj36T0Dj/WzExm7
4316L5nHs9f2H9I6uvSeiYfpbtORlZWdes/MI8t5edhp6SAfD8vgF0OFh9vJ
xyN713DzDa2NfDwedNYvGl3SRj4e3rVy1ScHvOTjUVqxbln3bQ/5eIRLTrUa
ajzkEzBry9vHrfKQT4B0atZhCbvJJyCh+daM0ekmn4Adh7LsKVvd5BNgvxLu
EzPd5BOQ9MtotOQJN/kEXG196fj4uEo+AUeksPbUoEo+AfU5jXnityr5BGQW
s0AkqJJPRNrT0b+aNJV8Il6ze9NjQ9QziWCJpwsne6lnFjFYVvTv5CD1rCKK
Nh1uHL5KPZuIDYk/rG6Yp55LRGTFmuDkczRvQMTnYw+4S6/SvAMiYo9e+lHY
TvNOiYhbkxeMqaN5DRLi3mg4ZtZo3mQJL5cFEpOuP/5+EnZ+8wLbmeIhn4Q9
e6q+37iN9mGVkHo/wz/dQvuwSVB21cVWjNE+XBJe/9379hznJZ+EmgP3T2of
P96vhDslN8ujP3nJJyEALTLEtZFPxt5bzeW99XRekmVsmq41LL1D58UkIzCf
fzautJ18MnpmJuJzhtvJJ2NS+6wpYUsH+WQs236vcMWVDvLJUJebRm9bOskn
o8Sa25v/D53ngYfvdV9lz33ZRT4ZxelD9r53zip93aHGxQaGaEX/4rIYn3Li
WO228DMM0t8XDjZYfEpp0ebM1mSG/HLzdMzPPkVKT50rNzLMtKx9vjbXryz8
ebN3vYlBs+/2Tvf49R4Y5s8scb/y1jm9Z2a4EeKHPg2f03vvMThHtvSk7Q/o
PSvDmFQwdfpFTe9VMqx2VdeMXNb0no2hwHn02lzreb3XwKDarjtqqoN6z8Vg
XLf1nvrRBb2nMiyPpD7JNYaUKddCksvP/v/f/AfuTw9X
      "]], 
     LineBox[CompressedData["
1:eJwt1Hk01fkfx3GNaRn1w4n2VNK0GGZ09/u99+ZVkxlNJiamXGS7rj37rrj2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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 30}, {0, 0.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811396791035194*^9, 3.811396864116877*^9, 
  3.811397058637785*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"e8781b25-da57-4025-b422-dd84edad5659"]
}, Open  ]],

Cell["\<\
Plot the forced longitude of pericentre as a function of semi-major axis (see \
Fig.7.5b).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ae266cd1-6411-4a15-83f7-d451be039ad0"],

Cell[CellGroupData[{

Cell["\<\
pfplot = ListPlot[Transpose[{adat,Mod[pfdat,360]}],
             Frame->True,PlotRange->{{0,30},{0,360}},
             Joined->True]\
\>", "Input",
 PageWidth:>Infinity,
 CellChangeTimes->{
  3.811396797763092*^9, {3.811397019725197*^9, 3.811397020464819*^9}},
 ShowSpecialCharacters->False,
 CellLabel->"In[22]:=",ExpressionUUID->"76da2839-9a5d-4d0f-9509-d26006b2e9e8"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw12Hc4Vv0Dx3FFCcle2Xvf7r1v50No2NmzJ0pFUhkNKfW09y4ilRZa8rRL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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 30}, {0, 360}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811396798705057*^9, 3.8113968642210693`*^9, 
  3.81139705872707*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"310d595d-91da-44d8-aedd-254d57cc684b"]
}, Open  ]],

Cell["\<\
Plot the forced inclination as a function of semi-major axis (see Fig.7.6a).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"48e90137-f286-4207-aa2c-401d779fdf12"],

Cell[CellGroupData[{

Cell["\<\
ifplot = ListPlot[Transpose[{adat,ifdat}],
             Frame->True,PlotRange->{{0,30},{0,3}},
             Joined->True]\
\>", "Input",
 PageWidth:>Infinity,
 CellChangeTimes->{
  3.8113968046299553`*^9, {3.811397026626997*^9, 3.8113970273259563`*^9}},
 ShowSpecialCharacters->False,
 CellLabel->"In[23]:=",ExpressionUUID->"7f25b1d3-fab6-4d94-a89b-ed696d73517c"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJwtzGtIU3EABfDrKp0MMobY0q33FLWHoQ0T57lhZTlaoX6woIfrsVlR9sGi
MLH8IJWBCrNcKxRRE0vtoVGUBqbYmj0oLJuX5rqItRB31bn+906zdg8czocD
v1WGM1nHJBRFqef7b9enK90uTSSIXLWiIYHgRUyYrKOxGaXb5M6NSQQth3Oy
YmqfIf/JNXVnyvxfXRF2UdMDe1unbWc6wWq/t9BpfYOWjC5v7W6C1w83nK4P
+oDJA43Sun0EPjavbjDpE4ZrxxNgJIhXmD+HmgYhY15SxecIDur6Q7S3h3BL
yaXmlxFUFvMpBe+GMROceT7cQuDKXfr0I+WE1mGvsLQSFHHte09aRrBE8ciu
6iWIKM/8tTDpB0bzQ/f0MwRtarb07gCLNKOUt/sIdnVfUiUbR2FU0I9NEbzo
jcHr6JCyGl70fsIlW1tg3s+Lnhux2qqV7GVe9H5DEs4N6B7wojeO5GXOsjyG
x9n71x0magLy7JI13+QC0i7k3ts8MIHIPqq3Si9AtkNdKLF4YBvbZLBWCvgq
57a+P85Bf2TdFR0joOF712Jr4iSUHmu0PtEvelNwuaMZm9kvelOIP9Hz6kbI
rOhNI7j1S4aufFb0vIhreqsNjp0TvRnklBiutrNzoudDnidOU3OUogOeDwrP
luZqjqID3h/0uaMOmZuC6IBHMHQzqmjELKEDHo+Kumx2O7OADngCptU1utTn
i+hw5tTy7jsCqP+R0n8BFtYiZA==
      "]], LineBox[CompressedData["
1:eJw91ntYDNgfx/GZZqYrTfeamqa5NCWEDHJJ81m0NlIpuW/llviRQu1PN1nZ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      "]], LineBox[CompressedData["
1:eJw11nk81fkex/GTvSJKdtKm4nCcfT95t9fUbZGSzIiKVpW2mWnGJCopMyRT
tJCSa0QLbdNKJVO0aBNpo1Ah+y7Xnb6f8895fB/f33md93n+dYYtXuvur8Xh
cLz7cDj/f78/0U5gNd8RnH9fBmh+WbRtQ4AjSpPWj/K8pIU/NgXZGIU4wiPN
MrO6pMNtjHH/8ynxjrgZpJJ1XWx0u5maPBNZjsjYfHnPgus1bt7jx1YVF/Se
t9Wu6/it0u3fXoUjlhacThAMfO/2b4/jhOcjyg0kb8u+9ax6zytqVnWIy7/1
RE74ZcTiMWf83n/rzXBCOg6NDK/98K0X4IRmj5umW+Mqv/VCnPDr7oJ68diP
bJ8Tap4F+fk++sT2OSHyS+H6sqnVbJ8T9g0LHz80pYbtc0LH19nH/6qqZfu4
WDdq6VOdvnVsHxdzonlJ5jF1bB8XAQ7+dntM6tk+Lor+9ny4cEc928dF+wDe
3MD6eraPixdukaP3z2tg+7gYzM1VxmY2sH1c5Ncl3x3Ut5Ht4+Kulm1Tmlcj
28eF3vcVyz4kN7J9zjDLWzhK/bmR7XPG5V22Y2xdmtg+ZyQ5Jr+uWNnE9jnj
dbz4j8bkJrbPGSMmpoZEv2xi+5zRFBRjqmPczPY54+lpsxO/uzWzfc74vtR4
SUBgM9vnjNJ3Dpybcc1snzOKv7TOeZjTzPa5YJN848tLVaxn5QLrJZWTThi1
sH0u8J5gnn+R38L2uWDiskUxJu4tbJ8LNEMStO4HtbB9Lggun97PILqF7XNB
m2rMopJ01stywYRl2y4s/If1Clxwtcmk9UgZ61W4QBSn8b/YyXocHnwub753
ybSV7eNhadSkuEynVraPh+yFB/XPoZXt42HGhnvi/HmtbB8PhTbJct2VrWwf
D0VdX8auCWa9eB4iTqQfHBjNelk8NJyc/KI9ifUKeCiL1X/Az2K9Ch6uLalN
u3GL9TiuyFoxROf0E9rnisot/d/pldM+V+xt23HnQT3tc8VG/dxsI04b2+eK
m39HrL5n1Mb2uWJK8fqefjZtbJ8r7Kftn/VsdBvb54ryA+tLeOI2ts8ViqnT
8m3BehWuSAur4yRPb3PLu3zpdz0OHxJ3R9O789vcYsN3LHxiyMdDg52e0X5t
bn4e7qOPWvHBX/L5Q/eqNjfeMPum1aP4SEw+f9hsc5tbR83nbIWIjzMjdo98
uZX1wEfuP6WNcyJYbwYfmyby3YNjWM+Lj2NmFt6+h1gvgI/Frzo4X4+z3gY+
BjefMvZKZ70QPgbmPOZtPMd6kXxcLdB/P+cq68XzMcu7J7bpFuul8BGXvTjC
J5/1snqf3xlfvfcx62XzkWa/7mF0MesV8FF/NMnxh7esV8yH9NHkl20VrFfR
ex/jfMq/hvUa+fA+Yep5opH8BPhh7svNf7eTnwCb8+IOHe8hPwFkiw+P89dt
Z34CzA0MeNrTr5359d77RZ7eaNLO/AS4UxJln2vWzvwE4E9JXdxg3c78BJDL
Qv7qtme9AAEOyCotqkay3gYBrnX8lJvpyHohAiyLVl734bFepAB7FvC0a4Ss
Fy+Avfub3T4y1ksRIMHr/bhzKtbLEmDXW+/+X9xYL7u3d9g3x3gi6xUIkHbs
R4nFVNYrFoDr08bXm8F6FQJY3lqz6dUs1msU4NKQtqtH5rIeRwjtkoOXp3iy
nqEQaVvjrUsXsp6VEL/Nzgn19iE/IUaln4u540d+Qnz9Q/Dezp/8hNjp59F/
8XLyE6Kve9H+favIT4h7q2eaZK0hPyG6jvt2ZQeRnxAOzd0l1zaSnxCfn8eM
TvuR/IRwslB47dxCfkJkzKwocw8mPyFyjOJEJiHkJwS3LPjC9VDyE2LRvGFP
fHaQnxCJPXtq6sLJTwid/FUBm3aTnxA3t0oOVUeSnxAhZydVzI8iPxGyR3AS
z+0lPxFOXK6x0oslPxGO9S9Onb6f/ET4JfHjwR1x7W6d//qJ8F33NfW5g+Qn
wvKt218UHSY/ETaYm16oSyA/ESa0d1v3HCU/EV7Py/hO+zjrbRBhjPH6nd3J
5CfCjX3xRrUp5CeCsDjE7lkq+YmQsTOlPjON/ESQel29FZ7OelkiKPMv5s89
RX4iRBiUuVmcIT8RFskqPR6fJT8RNg75oNmRRX69zwt+duafZ71GEbj6D2Y/
uUB+YtRMTC1ec4n8xHirvaFJ6zL5iTHv/PT7UVfIT4yU342izK6RnxiRW75f
Enud/MQYm3Z6vWE2+YmxPdX7fXAO+Ynhb374ddVN8hOjm3Nk539uk5+4939b
GCc9l/zE8Bzx01qdPPITw+Svk83z/yE/MUL2Lj53/C75iXFWqzP/0z3yE+N4
RJO3cwH5iZEtbw1dfp/8xNgVWuKT+ID8xJjx5KRh4UPyE+N59bnU7kfkJ8Za
vdCZDo/JT4LHWZWWU5+QnwTb/zQYHvCU/CQ48XRh2NZn5CfB7tUZ82Kfk58E
Aya6nE0uIj8JTlquzDjzgvwk4Gm8/S4Vk58Ej1yWll8pIT8JvDsXTLvykvwk
sI8KTb1QSn6957vHzE69Ij8J9La0JSe9Jj8J5isnrNz7hvwkGDw076fgt+Qn
gafH7HL/d+QnQUOE9Op3ZeQngft8XzPncvKToDBwMqffe/KTIPZ2y+/v35Of
BK9iLR5e+UB+UjRM//QkqoL8pAjxmZnuW0l+UgTp3l7GqyI/KarL15i1V5Gf
FIcOWN7O/kh+UlwXiUJ3fCI/KfRSX/4w5TP5SXHPtHSpXjX59X6f3qnkm9Xk
J0Vlxq9Ov9aQnxS5DaO0RbXkJ0X29nGqylryk+LuM8s3cV/ITwoTvayOKXXk
J0V4dmF8Ux35SdFq0JSXUE9+vb+n0zN6cgP5SVEX0tX9uYH8pEj9cswmqpH8
pJiV+qjRtYn8ZLiX+Cj6QRP5ydD37bmulc3kJ0Npl+c43RbykyE32Gf5kRby
k8FKI/9F1Ep+Mry9Oiwsr5X8ZIgIcojwaiM/GSZr2+3/2EZ+MlTYXsz8sZ38
ZFhtEFCp3UF+MoRpB6v/6CA/GbS8h1w27yQ/GUJmjVt+pJP8ZNAZkTVzeBf5
yaBrb7npRBf5yTBgX3XZqG7yk0FcsCMxpZv8ZIjSNc0c+ZX8ZBC5JwxL+kp+
MniHGDXb9JCfHEdbhov+7CE/OR7v/q3MkNPB/OSwm5vQN6z3/M1PjrlBb061
9p6/+cmR++K3Fyv7dDA/OS4OOBhZ2nv+5ifHgQ+uhTO0WM9LDqVoWPoVLdYL
kMMpVDDCUZv1Nsihua6v/lOb9ULkiCnldfVos16kHOZbzVes0GG9eDlu7TPd
VajDeilyJH3x9ZHrsl6WHNc+2Ncf0WW9bDlEJQsmaemxXoEcHoWdi/z1WK9Y
DofOt5Py9FivQo7xqrudo/VZr1EOdYbPznB91uMosMdB8umDPusZKjDj9D3u
BAPyU+Ck3q5ZiQbkp4CXSY5XhwH5KXD/P+dnevQlPwWuzYwWZvQlPwVO26/s
q9uP/BQoOD+lyLsf+SnQ5mlz9Gw/8lNgtm7uMr3+5KcAt3iQcGF/8lPg0Ooc
rYz+5KdAsOTXV1/7k58Ck8pf5c4yJL/e+7/X3Ug0JD8FbKtO3a81JD8FEt9p
NamNyE+BMafzJLuNyE+BmPHT9j83Ij8FVt+5bTl8APkpMbZ6efbqAeSnxH35
/OgLA8hPiX0zE/f0DCA/JX6STjs/xZj8lHieMt0kypj8lCicujfxmTH5KaHT
1epvY0J+SiRYzgnwNSE/Jfqc8TuebEJ+StzNL7OvMiE/JYJPbnvtNJD8lEjl
vH23eiD5KXHBMdb51EDyU2LVKsec2oHkp4Su49BjvEHkp4SlTW1h4CDyU8Jl
x1f39EHkp4TDyszRnwaRnxKhN3zdR5uSnxLfJ85/tsSU/FQI/LkoM9GU/FQo
GW9XU2JKfironFiw02ww+amg5J4NmTWY/FTYtnbS612DyU+FiZO5STmDyU+F
4R/X5rcPJj8Vbgy1XCQwIz8VzgYO9VluRn4qRPCD7yWYkZ8KNY+sU56akZ8K
PeWvGvqak58KWXOOZ441Jz8VjvyMyvXm5KfCxflhMSnm5KdC5DHhhWJz8lMh
rNXIw9CC/FQ42HA/cKwF+ang4jFSd50F+akwaehVmyQL8lPD5Loiq9CC/NR4
aK6638eS/NRozvJcJbAkPzXelA6N8rUkPzWOZg1TRlmSnxrhc94EXrMkPzVy
yl5wP1PPS43MnPBNllbkp0bg3kUzJlmRnxofPR+cDbIiPzXCDqj/e8SK/NTQ
Wm7Eu2tFfmoMi0qY0kS9FDVi4qY2D7EmPzW21vjIp1mTnxqJn10HbbAmPzXu
dOpsP2xNfmoYpw6PyrUmPzVCz/4jrqVeoxrzHISbzW3IT4PbQX96jLUhPw2C
t4ws9LchPw0OpRvWRNqQnwbjB/34V5YN+Wnwyn+Xfgn1oEHDSD8Dji359X7+
mF2Ggy35aZBq9bzlO1vy02DO9YSKtbbkp8H5h+HBsbbkp0FR6pGrl6gXqcGq
wqrkUurFayAbsEbGsSM/DbhBvE0j7MhPA/WK0Ysm25GfBnmF7i3L7chPg8I+
/1XtsSM/DT6VmPMzqFehwcOivU8fUK9Rg8vWOk51vef/AR1kYe0=
      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 30}, {0, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113968055061617`*^9, 3.811396864288742*^9, 
  3.811397058795061*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"37fad0bd-81e8-47f6-8e37-33508b9d8076"]
}, Open  ]],

Cell["\<\
Plot the forced longitude of ascending node as a function of semi-major axis \
(see Fig.7.6b).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9a03a3cc-1304-4185-855e-cbbc550efb9e"],

Cell[CellGroupData[{

Cell["\<\
nfplot = ListPlot[Transpose[{adat,Mod[nfdat,360]}],
             Frame->True,PlotRange->{{0,30},{0,360}},
             Joined->True]\
\>", "Input",
 PageWidth:>Infinity,
 CellChangeTimes->{
  3.811396810098503*^9, {3.811397032314898*^9, 3.811397033096002*^9}},
 ShowSpecialCharacters->False,
 CellLabel->"In[24]:=",ExpressionUUID->"f7648221-90f7-47bb-a3c7-e5d9290d43a3"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["

1:eJw92HdYzf0fx/EWSWhvpb3XWY1TOS+rlCINnc5pqGgnZBRFRlbZNykkO0SU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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 30}, {0, 360}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113968109393797`*^9, 3.81139686435979*^9, 
  3.811397058853547*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"400dd20d-2841-4f18-965c-14dd2c7094f8"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{912, 653},
WindowMargins->{{18, Automatic}, {366, Automatic}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"1af8712c-3c29-4ac9-a309-8e69f42906e3"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 96, 0, 67, "Section",ExpressionUUID->"3ee60461-44c2-40ac-9506-5ddf58e33a63"],
Cell[657, 22, 475, 12, 95, "Text",ExpressionUUID->"37be38bd-2803-4bd7-ac96-d8eee2b1b416"],
Cell[1135, 36, 4775, 146, 2568, "Input",ExpressionUUID->"5c704d32-0f85-4403-a895-45a1604b6428"],
Cell[5913, 184, 336, 10, 53, "Text",ExpressionUUID->"2e9e3caf-c152-46bc-92b1-e90ba07337d9"],
Cell[6252, 196, 450, 16, 228, "Input",ExpressionUUID->"07b26879-78d8-4f11-bd0a-d76ed7a87d31"],
Cell[6705, 214, 353, 9, 76, "Text",ExpressionUUID->"662f21a2-b317-4507-af2b-95832ea6ae72"],
Cell[7061, 225, 1542, 41, 678, "Input",ExpressionUUID->"c623892b-23df-48e2-8ce8-3f29f51004fe"],
Cell[8606, 268, 577, 19, 76, "Text",ExpressionUUID->"2f8a5dda-193b-4399-af6a-6654ed22c761"],
Cell[9186, 289, 550, 18, 264, "Input",ExpressionUUID->"f1162b10-f35b-4ad3-9f60-6b592fc5f88e"],
Cell[9739, 309, 170, 3, 53, "Text",ExpressionUUID->"564a21d4-8a15-4db0-b1b2-c438826011fc"],
Cell[9912, 314, 173, 3, 30, "Input",ExpressionUUID->"c77417f9-edc5-4dd7-bb9a-72d807ea7ecf"],
Cell[10088, 319, 389, 8, 76, "Text",ExpressionUUID->"6ed3178b-b2be-4db8-ba71-6f8ec0cc31d0"],
Cell[10480, 329, 277, 10, 120, "Input",ExpressionUUID->"f6e9cb09-03f4-4c91-ad16-459ddee14345"],
Cell[10760, 341, 197, 5, 53, "Text",ExpressionUUID->"9b401429-81d7-4e11-94eb-930de94e0f83"],
Cell[CellGroupData[{
Cell[10982, 350, 376, 9, 66, "Input",ExpressionUUID->"681867ba-2ded-409c-8fba-c6c4c571fd78"],
Cell[11361, 361, 8837, 161, 245, "Output",ExpressionUUID->"77841e37-4e24-4fb1-956d-6b7feec12790"]
}, Open  ]],
Cell[20213, 525, 204, 5, 53, "Text",ExpressionUUID->"cf8b70f8-e9fe-42d2-b558-00be3d00f974"],
Cell[20420, 532, 410, 9, 102, "Input",ExpressionUUID->"742e3cdc-0e6e-46c5-bcf4-312132224855"],
Cell[20833, 543, 215, 6, 53, "Text",ExpressionUUID->"5d7f88d1-17bb-491d-9de1-a291845e8ed7"],
Cell[CellGroupData[{
Cell[21073, 553, 213, 4, 30, "Input",ExpressionUUID->"f083dc9b-47f9-4338-962f-44c518c79ed4"],
Cell[21289, 559, 9154, 165, 245, "Output",ExpressionUUID->"6eafdb37-90bf-470c-8505-2b1cbb825cdb"]
}, Open  ]],
Cell[30458, 727, 213, 6, 53, "Text",ExpressionUUID->"94eb1f9f-cb11-48e0-b250-782c103d3cd2"],
Cell[CellGroupData[{
Cell[30696, 737, 371, 9, 66, "Input",ExpressionUUID->"b54344f3-f291-4818-a064-4aa0cce1d443"],
Cell[31070, 748, 10020, 181, 245, "Output",ExpressionUUID->"e8781b25-da57-4025-b422-dd84edad5659"]
}, Open  ]],
Cell[41105, 932, 224, 6, 53, "Text",ExpressionUUID->"ae266cd1-6411-4a15-83f7-d451be039ad0"],
Cell[CellGroupData[{
Cell[41354, 942, 380, 9, 66, "Input",ExpressionUUID->"76da2839-9a5d-4d0f-9509-d26006b2e9e8"],
Cell[41737, 953, 9647, 172, 241, "Output",ExpressionUUID->"310d595d-91da-44d8-aedd-254d57cc684b"]
}, Open  ]],
Cell[51399, 1128, 210, 5, 53, "Text",ExpressionUUID->"48e90137-f286-4207-aa2c-401d779fdf12"],
Cell[CellGroupData[{
Cell[51634, 1137, 373, 9, 66, "Input",ExpressionUUID->"7f25b1d3-fab6-4d94-a89b-ed696d73517c"],
Cell[52010, 1148, 9544, 172, 248, "Output",ExpressionUUID->"37fad0bd-81e8-47f6-8e37-33508b9d8076"]
}, Open  ]],
Cell[61569, 1323, 228, 6, 53, "Text",ExpressionUUID->"9a03a3cc-1304-4185-855e-cbbc550efb9e"],
Cell[CellGroupData[{
Cell[61822, 1333, 380, 9, 66, "Input",ExpressionUUID->"f7648221-90f7-47bb-a3c7-e5d9290d43a3"],
Cell[62205, 1344, 9334, 167, 264, "Output",ExpressionUUID->"400dd20d-2841-4f18-965c-14dd2c7094f8"]
}, Open  ]]
}
]
*)

